@@ -1,6 +1,6 @@
 from haystack_integrations.components.generators.llama_cpp import LlamaCppGenerator
 
-generator = LlamaCppGenerator(model_path="openchat-3.5-1210.Q3_K_S.gguf", n_ctx=512, n_batch=128)
+generator = LlamaCppGenerator(model="openchat-3.5-1210.Q3_K_S.gguf", n_ctx=512, n_batch=128)
 generator.warm_up()
 
 question = "Who is the best American actor?"
