@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2024-present deepset GmbH <info@deepset.ai>
+#
+# SPDX-License-Identifier: Apache-2.0
+
 import json
 from collections.abc import Iterator
 from datetime import datetime, timezone
@@ -201,7 +205,7 @@ class LlamaCppChatGenerator:
         streaming_callback: StreamingCallbackT | None = None,
         chat_handler_name: str | None = None,
         model_clip_path: str | None = None,
-    ):
+    ) -> None:
         """
         :param model: The path of a quantized model for text generation, for example, "zephyr-7b-beta.Q4_0.gguf".
             If the model path is also specified in the `model_kwargs`, this parameter will be ignored.
@@ -263,7 +267,7 @@ class LlamaCppChatGenerator:
         self.model_clip_path = model_clip_path
         self._handler = handler
 
-    def warm_up(self):
+    def warm_up(self) -> None:
         if self._model is not None:
             return
 
@@ -347,8 +351,7 @@ class LlamaCppChatGenerator:
             - `replies`: The responses from the model
         """
         if self._model is None:
-            error_msg = "The model has not been loaded. Please call warm_up() before running."
-            raise RuntimeError(error_msg)
+            self.warm_up()
 
         if not messages:
             return {"replies": []}
@@ -381,7 +384,7 @@ class LlamaCppChatGenerator:
         )
 
         if streaming_callback:
-            response_stream = self._model.create_chat_completion(
+            response_stream = self._model.create_chat_completion(  # type: ignore[union-attr]
                 messages=formatted_messages, tools=llamacpp_tools, **updated_generation_kwargs, stream=True
             )
             return self._handle_streaming_response(
@@ -391,7 +394,7 @@ class LlamaCppChatGenerator:
             )  # we know that response_stream is Iterator[CreateChatCompletionStreamResponse]
             # because create_chat_completion was called with stream=True, but mypy doesn't know that
 
-        response = self._model.create_chat_completion(
+        response = self._model.create_chat_completion(  # type: ignore[union-attr]
             messages=formatted_messages, tools=llamacpp_tools, **updated_generation_kwargs
         )
         replies = []
@@ -399,8 +402,11 @@ class LlamaCppChatGenerator:
             msg = f"Expected a dictionary response, got a different object: {response}"
             raise ValueError(msg)
 
-        for choice in response["choices"]:
-            chat_message = self._convert_chat_completion_choice_to_chat_message(choice, response)
+        for choice in response["choices"]:  # type: ignore[index]
+            chat_message = self._convert_chat_completion_choice_to_chat_message(
+                choice,
+                response,  # type: ignore[arg-type]
+            )
             replies.append(chat_message)
         return {"replies": replies}
 
